#!/usr/bin/env python
# coding: utf-8

from setuptools import setup
from setuptools.command.install import install
setup(
    name='security_test',
    version='1.0.1',
    author='security_test',
    author_email='security_test@github.com',
    url='https://github.com/security_test',
    description='security_test',
    packages=['security_test'],
)
